# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/broadcast/message/esports/notify.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/bilibili/broadcast/message/esports/notify.proto\x12\"bilibili.broadcast.message.esports\"\x15\n\x06Notify\x12\x0b\n\x03\x63id\x18\x01 \x01(\x03\x62\x06proto3')



_NOTIFY = DESCRIPTOR.message_types_by_name['Notify']
Notify = _reflection.GeneratedProtocolMessageType('Notify', (_message.Message,), {
  'DESCRIPTOR' : _NOTIFY,
  '__module__' : 'bilibili.broadcast.message.esports.notify_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.broadcast.message.esports.Notify)
  })
_sym_db.RegisterMessage(Notify)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _NOTIFY._serialized_start=87
  _NOTIFY._serialized_end=108
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _ClipType:
    ValueType = typing.NewType('ValueType', builtins.int)
    V: typing_extensions.TypeAlias = ValueType
class _ClipTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ClipType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    NT_UNKNOWN: _ClipType.ValueType  # 0
    """"""

    CLIP_TYPE_OP: _ClipType.ValueType  # 1
    """"""

    CLIP_TYPE_ED: _ClipType.ValueType  # 2
    """"""

    CLIP_TYPE_HE: _ClipType.ValueType  # 3
    """"""

    CLIP_TYPE_MULTI_VIEW: _ClipType.ValueType  # 4
    """"""

class ClipType(_ClipType, metaclass=_ClipTypeEnumTypeWrapper):
    pass

NT_UNKNOWN: ClipType.ValueType  # 0
""""""

CLIP_TYPE_OP: ClipType.ValueType  # 1
""""""

CLIP_TYPE_ED: ClipType.ValueType  # 2
""""""

CLIP_TYPE_HE: ClipType.ValueType  # 3
""""""

CLIP_TYPE_MULTI_VIEW: ClipType.ValueType  # 4
""""""

global___ClipType = ClipType


class _CodeType:
    ValueType = typing.NewType('ValueType', builtins.int)
    V: typing_extensions.TypeAlias = ValueType
class _CodeTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_CodeType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    NOCODE: _CodeType.ValueType  # 0
    """默认"""

    CODE264: _CodeType.ValueType  # 1
    """H.264"""

    CODE265: _CodeType.ValueType  # 2
    """H.265"""

class CodeType(_CodeType, metaclass=_CodeTypeEnumTypeWrapper):
    """编码类型"""
    pass

NOCODE: CodeType.ValueType  # 0
"""默认"""

CODE264: CodeType.ValueType  # 1
"""H.264"""

CODE265: CodeType.ValueType  # 2
"""H.265"""

global___CodeType = CodeType


class _DrmTechType:
    ValueType = typing.NewType('ValueType', builtins.int)
    V: typing_extensions.TypeAlias = ValueType
class _DrmTechTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_DrmTechType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    NON: _DrmTechType.ValueType  # 0
    """"""

    FAIR_PLAY: _DrmTechType.ValueType  # 1
    """"""

class DrmTechType(_DrmTechType, metaclass=_DrmTechTypeEnumTypeWrapper):
    """"""
    pass

NON: DrmTechType.ValueType  # 0
""""""

FAIR_PLAY: DrmTechType.ValueType  # 1
""""""

global___DrmTechType = DrmTechType


class _InlineScene:
    ValueType = typing.NewType('ValueType', builtins.int)
    V: typing_extensions.TypeAlias = ValueType
class _InlineSceneEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_InlineScene.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UNKNOWN: _InlineScene.ValueType  # 0
    """"""

    RELATED_EP: _InlineScene.ValueType  # 1
    """"""

    HE: _InlineScene.ValueType  # 2
    """"""

    SKIP: _InlineScene.ValueType  # 3
    """"""

class InlineScene(_InlineScene, metaclass=_InlineSceneEnumTypeWrapper):
    """"""
    pass

UNKNOWN: InlineScene.ValueType  # 0
""""""

RELATED_EP: InlineScene.ValueType  # 1
""""""

HE: InlineScene.ValueType  # 2
""""""

SKIP: InlineScene.ValueType  # 3
""""""

global___InlineScene = InlineScene


class _InlineType:
    ValueType = typing.NewType('ValueType', builtins.int)
    V: typing_extensions.TypeAlias = ValueType
class _InlineTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_InlineType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    TYPE_UNKNOWN: _InlineType.ValueType  # 0
    """"""

    TYPE_WHOLE: _InlineType.ValueType  # 1
    """"""

    TYPE_HE_CLIP: _InlineType.ValueType  # 2
    """"""

    TYPE_PREVIEW: _InlineType.ValueType  # 3
    """"""

class InlineType(_InlineType, metaclass=_InlineTypeEnumTypeWrapper):
    """"""
    pass

TYPE_UNKNOWN: InlineType.ValueType  # 0
""""""

TYPE_WHOLE: InlineType.ValueType  # 1
""""""

TYPE_HE_CLIP: InlineType.ValueType  # 2
""""""

TYPE_PREVIEW: InlineType.ValueType  # 3
""""""

global___InlineType = InlineType


class _PlayErr:
    ValueType = typing.NewType('ValueType', builtins.int)
    V: typing_extensions.TypeAlias = ValueType
class _PlayErrEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_PlayErr.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    NoErr: _PlayErr.ValueType  # 0
    """"""

    WithMultiDeviceLoginErr: _PlayErr.ValueType  # 1
    """管控类型的错误码"""

class PlayErr(_PlayErr, metaclass=_PlayErrEnumTypeWrapper):
    """错误码"""
    pass

NoErr: PlayErr.ValueType  # 0
""""""

WithMultiDeviceLoginErr: PlayErr.ValueType  # 1
"""管控类型的错误码"""

global___PlayErr = PlayErr


class BadgeInfo(google.protobuf.message.Message):
    """角标信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TEXT_FIELD_NUMBER: builtins.int
    BG_COLOR_FIELD_NUMBER: builtins.int
    BG_COLOR_NIGHT_FIELD_NUMBER: builtins.int
    TEXT_COLOR_FIELD_NUMBER: builtins.int
    BG_GRADIENT_COLOR_FIELD_NUMBER: builtins.int
    text: typing.Text
    """角标文案"""

    bg_color: typing.Text
    """角标色值"""

    bg_color_night: typing.Text
    """角标色值-夜间模式"""

    text_color: typing.Text
    """文案色值"""

    @property
    def bg_gradient_color(self) -> global___GradientColor:
        """"""
        pass
    def __init__(self,
        *,
        text: typing.Text = ...,
        bg_color: typing.Text = ...,
        bg_color_night: typing.Text = ...,
        text_color: typing.Text = ...,
        bg_gradient_color: typing.Optional[global___GradientColor] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["bg_gradient_color",b"bg_gradient_color"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bg_color",b"bg_color","bg_color_night",b"bg_color_night","bg_gradient_color",b"bg_gradient_color","text",b"text","text_color",b"text_color"]) -> None: ...
global___BadgeInfo = BadgeInfo

class BottomDisplay(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TITLE_FIELD_NUMBER: builtins.int
    ICON_FIELD_NUMBER: builtins.int
    @property
    def title(self) -> global___TextInfo:
        """"""
        pass
    icon: typing.Text
    """"""

    def __init__(self,
        *,
        title: typing.Optional[global___TextInfo] = ...,
        icon: typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["title",b"title"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["icon",b"icon","title",b"title"]) -> None: ...
global___BottomDisplay = BottomDisplay

class ButtonInfo(google.protobuf.message.Message):
    """按钮信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    class OrderReportParamsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor
        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: typing.Text
        value: typing.Text
        def __init__(self,
            *,
            key: typing.Text = ...,
            value: typing.Text = ...,
            ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key",b"key","value",b"value"]) -> None: ...

    TEXT_FIELD_NUMBER: builtins.int
    TEXT_COLOR_FIELD_NUMBER: builtins.int
    TEXT_COLOR_NIGHT_FIELD_NUMBER: builtins.int
    BG_COLOR_FIELD_NUMBER: builtins.int
    BG_COLOR_NIGHT_FIELD_NUMBER: builtins.int
    LINK_FIELD_NUMBER: builtins.int
    ACTION_TYPE_FIELD_NUMBER: builtins.int
    BADGE_INFO_FIELD_NUMBER: builtins.int
    REPORT_FIELD_NUMBER: builtins.int
    LEFT_STRIKETHROUGH_TEXT_FIELD_NUMBER: builtins.int
    SIMPLE_TEXT_INFO_FIELD_NUMBER: builtins.int
    SIMPLE_BG_COLOR_FIELD_NUMBER: builtins.int
    SIMPLE_BG_COLOR_NIGHT_FIELD_NUMBER: builtins.int
    BG_GRADIENT_COLOR_FIELD_NUMBER: builtins.int
    ORDER_REPORT_PARAMS_FIELD_NUMBER: builtins.int
    text: typing.Text
    """按钮文案"""

    text_color: typing.Text
    """按钮字体色值"""

    text_color_night: typing.Text
    """按钮字体色值-夜间模式"""

    bg_color: typing.Text
    """按钮背景色"""

    bg_color_night: typing.Text
    """按钮背景色-夜间模式"""

    link: typing.Text
    """按钮链接"""

    action_type: typing.Text
    """按钮动作类型"""

    @property
    def badge_info(self) -> global___BadgeInfo:
        """角标信息"""
        pass
    @property
    def report(self) -> global___Report:
        """埋点上报信息"""
        pass
    left_strikethrough_text: typing.Text
    """左侧删除线样式文案"""

    @property
    def simple_text_info(self) -> global___TextInfo:
        """缩略按钮文案信息"""
        pass
    simple_bg_color: typing.Text
    """缩略按钮背景色值"""

    simple_bg_color_night: typing.Text
    """缩略按钮字体色值-夜间模式"""

    @property
    def bg_gradient_color(self) -> global___GradientColor:
        """"""
        pass
    @property
    def order_report_params(self) -> google.protobuf.internal.containers.ScalarMap[typing.Text, typing.Text]:
        """"""
        pass
    def __init__(self,
        *,
        text: typing.Text = ...,
        text_color: typing.Text = ...,
        text_color_night: typing.Text = ...,
        bg_color: typing.Text = ...,
        bg_color_night: typing.Text = ...,
        link: typing.Text = ...,
        action_type: typing.Text = ...,
        badge_info: typing.Optional[global___BadgeInfo] = ...,
        report: typing.Optional[global___Report] = ...,
        left_strikethrough_text: typing.Text = ...,
        simple_text_info: typing.Optional[global___TextInfo] = ...,
        simple_bg_color: typing.Text = ...,
        simple_bg_color_night: typing.Text = ...,
        bg_gradient_color: typing.Optional[global___GradientColor] = ...,
        order_report_params: typing.Optional[typing.Mapping[typing.Text, typing.Text]] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["badge_info",b"badge_info","bg_gradient_color",b"bg_gradient_color","report",b"report","simple_text_info",b"simple_text_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["action_type",b"action_type","badge_info",b"badge_info","bg_color",b"bg_color","bg_color_night",b"bg_color_night","bg_gradient_color",b"bg_gradient_color","left_strikethrough_text",b"left_strikethrough_text","link",b"link","order_report_params",b"order_report_params","report",b"report","simple_bg_color",b"simple_bg_color","simple_bg_color_night",b"simple_bg_color_night","simple_text_info",b"simple_text_info","text",b"text","text_color",b"text_color","text_color_night",b"text_color_night"]) -> None: ...
global___ButtonInfo = ButtonInfo

class CastTips(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    CODE_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    code: builtins.int
    """"""

    message: typing.Text
    """"""

    def __init__(self,
        *,
        code: builtins.int = ...,
        message: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["code",b"code","message",b"message"]) -> None: ...
global___CastTips = CastTips

class ClipInfo(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MATERIAL_NO_FIELD_NUMBER: builtins.int
    START_FIELD_NUMBER: builtins.int
    END_FIELD_NUMBER: builtins.int
    CLIP_TYPE_FIELD_NUMBER: builtins.int
    TOAST_TEXT_FIELD_NUMBER: builtins.int
    MULTI_VIEW_FIELD_NUMBER: builtins.int
    material_no: builtins.int
    """"""

    start: builtins.int
    """"""

    end: builtins.int
    """"""

    clip_type: global___ClipType.ValueType
    """"""

    toast_text: typing.Text
    """"""

    @property
    def multi_view(self) -> global___MultiView:
        """"""
        pass
    def __init__(self,
        *,
        material_no: builtins.int = ...,
        start: builtins.int = ...,
        end: builtins.int = ...,
        clip_type: global___ClipType.ValueType = ...,
        toast_text: typing.Text = ...,
        multi_view: typing.Optional[global___MultiView] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["multi_view",b"multi_view"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["clip_type",b"clip_type","end",b"end","material_no",b"material_no","multi_view",b"multi_view","start",b"start","toast_text",b"toast_text"]) -> None: ...
global___ClipInfo = ClipInfo

class ContinuePlayInfo(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    CONTINUE_PLAY_EP_ID_FIELD_NUMBER: builtins.int
    continue_play_ep_id: builtins.int
    """"""

    def __init__(self,
        *,
        continue_play_ep_id: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["continue_play_ep_id",b"continue_play_ep_id"]) -> None: ...
global___ContinuePlayInfo = ContinuePlayInfo

class Coupon(google.protobuf.message.Message):
    """优惠券"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    COUPON_TOKEN_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    USE_DESC_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    PAY_BUTTON_TEXT_FIELD_NUMBER: builtins.int
    PAY_BUTTON_TEXT_LINE_THROUGH_FIELD_NUMBER: builtins.int
    REAL_AMOUNT_FIELD_NUMBER: builtins.int
    EXPIRE_TIME_FIELD_NUMBER: builtins.int
    coupon_token: typing.Text
    """优惠券token"""

    type: builtins.int
    """优惠券类型
    1:折扣券 2:满减券 3:兑换券
    """

    value: typing.Text
    """优惠券面值"""

    use_desc: typing.Text
    """优惠券使用描述"""

    title: typing.Text
    """优惠券标题"""

    desc: typing.Text
    """优惠券描述"""

    pay_button_text: typing.Text
    """优惠券支付按钮文案"""

    pay_button_text_line_through: typing.Text
    """优惠券支付按钮删除线文案"""

    real_amount: typing.Text
    """实付金额"""

    @property
    def expire_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """使用过期时间"""
        pass
    def __init__(self,
        *,
        coupon_token: typing.Text = ...,
        type: builtins.int = ...,
        value: typing.Text = ...,
        use_desc: typing.Text = ...,
        title: typing.Text = ...,
        desc: typing.Text = ...,
        pay_button_text: typing.Text = ...,
        pay_button_text_line_through: typing.Text = ...,
        real_amount: typing.Text = ...,
        expire_time: typing.Optional[google.protobuf.timestamp_pb2.Timestamp] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["expire_time",b"expire_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["coupon_token",b"coupon_token","desc",b"desc","expire_time",b"expire_time","pay_button_text",b"pay_button_text","pay_button_text_line_through",b"pay_button_text_line_through","real_amount",b"real_amount","title",b"title","type",b"type","use_desc",b"use_desc","value",b"value"]) -> None: ...
global___Coupon = Coupon

class CouponInfo(google.protobuf.message.Message):
    """优惠券信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TOAST_FIELD_NUMBER: builtins.int
    POP_WIN_FIELD_NUMBER: builtins.int
    @property
    def toast(self) -> global___CouponToast:
        """提示框信息"""
        pass
    @property
    def pop_win(self) -> global___PopWin:
        """弹窗信息"""
        pass
    def __init__(self,
        *,
        toast: typing.Optional[global___CouponToast] = ...,
        pop_win: typing.Optional[global___PopWin] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pop_win",b"pop_win","toast",b"toast"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pop_win",b"pop_win","toast",b"toast"]) -> None: ...
global___CouponInfo = CouponInfo

class CouponTextInfo(google.protobuf.message.Message):
    """优惠券提示框文案信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    POSITIVE_PREVIEW_FIELD_NUMBER: builtins.int
    SECTION_FIELD_NUMBER: builtins.int
    positive_preview: typing.Text
    """提示框文案-播正片6分钟预览"""

    section: typing.Text
    """提示框文案-播非正片分节ep"""

    def __init__(self,
        *,
        positive_preview: typing.Text = ...,
        section: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["positive_preview",b"positive_preview","section",b"section"]) -> None: ...
global___CouponTextInfo = CouponTextInfo

class CouponToast(google.protobuf.message.Message):
    """优惠券提示框信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TEXT_INFO_FIELD_NUMBER: builtins.int
    BUTTON_FIELD_NUMBER: builtins.int
    @property
    def text_info(self) -> global___CouponTextInfo:
        """提示框文案信息"""
        pass
    @property
    def button(self) -> global___ButtonInfo:
        """提示框按钮"""
        pass
    def __init__(self,
        *,
        text_info: typing.Optional[global___CouponTextInfo] = ...,
        button: typing.Optional[global___ButtonInfo] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["button",b"button","text_info",b"text_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["button",b"button","text_info",b"text_info"]) -> None: ...
global___CouponToast = CouponToast

class DashItem(google.protobuf.message.Message):
    """dash条目"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ID_FIELD_NUMBER: builtins.int
    BASE_URL_FIELD_NUMBER: builtins.int
    BACKUP_URL_FIELD_NUMBER: builtins.int
    BANDWIDTH_FIELD_NUMBER: builtins.int
    CODECID_FIELD_NUMBER: builtins.int
    MD5_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    FRAME_RATE_FIELD_NUMBER: builtins.int
    id: builtins.int
    """清晰度"""

    base_url: typing.Text
    """主线流"""

    @property
    def backup_url(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]:
        """备用流"""
        pass
    bandwidth: builtins.int
    """带宽"""

    codecid: builtins.int
    """编码id"""

    md5: typing.Text
    """md5"""

    size: builtins.int
    """大小"""

    frame_rate: typing.Text
    """帧率"""

    def __init__(self,
        *,
        id: builtins.int = ...,
        base_url: typing.Text = ...,
        backup_url: typing.Optional[typing.Iterable[typing.Text]] = ...,
        bandwidth: builtins.int = ...,
        codecid: builtins.int = ...,
        md5: typing.Text = ...,
        size: builtins.int = ...,
        frame_rate: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["backup_url",b"backup_url","bandwidth",b"bandwidth","base_url",b"base_url","codecid",b"codecid","frame_rate",b"frame_rate","id",b"id","md5",b"md5","size",b"size"]) -> None: ...
global___DashItem = DashItem

class DashVideo(google.protobuf.message.Message):
    """dash视频流"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    BASE_URL_FIELD_NUMBER: builtins.int
    BACKUP_URL_FIELD_NUMBER: builtins.int
    BANDWIDTH_FIELD_NUMBER: builtins.int
    CODECID_FIELD_NUMBER: builtins.int
    MD5_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    AUDIO_ID_FIELD_NUMBER: builtins.int
    NO_REXCODE_FIELD_NUMBER: builtins.int
    FRAME_RATE_FIELD_NUMBER: builtins.int
    WIDTH_FIELD_NUMBER: builtins.int
    HEIGHT_FIELD_NUMBER: builtins.int
    base_url: typing.Text
    """主线流"""

    @property
    def backup_url(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]:
        """备用流"""
        pass
    bandwidth: builtins.int
    """带宽"""

    codecid: builtins.int
    """编码id"""

    md5: typing.Text
    """md5"""

    size: builtins.int
    """大小"""

    audio_id: builtins.int
    """伴音质量id"""

    no_rexcode: builtins.bool
    """是否非全二压"""

    frame_rate: typing.Text
    """帧率"""

    width: builtins.int
    """宽"""

    height: builtins.int
    """高"""

    def __init__(self,
        *,
        base_url: typing.Text = ...,
        backup_url: typing.Optional[typing.Iterable[typing.Text]] = ...,
        bandwidth: builtins.int = ...,
        codecid: builtins.int = ...,
        md5: typing.Text = ...,
        size: builtins.int = ...,
        audio_id: builtins.int = ...,
        no_rexcode: builtins.bool = ...,
        frame_rate: typing.Text = ...,
        width: builtins.int = ...,
        height: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["audio_id",b"audio_id","backup_url",b"backup_url","bandwidth",b"bandwidth","base_url",b"base_url","codecid",b"codecid","frame_rate",b"frame_rate","height",b"height","md5",b"md5","no_rexcode",b"no_rexcode","size",b"size","width",b"width"]) -> None: ...
global___DashVideo = DashVideo

class Dialog(google.protobuf.message.Message):
    """鉴权浮层"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    CODE_FIELD_NUMBER: builtins.int
    MSG_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    STYLE_TYPE_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    SUBTITLE_FIELD_NUMBER: builtins.int
    IMAGE_FIELD_NUMBER: builtins.int
    BUTTON_FIELD_NUMBER: builtins.int
    BOTTOM_DESC_FIELD_NUMBER: builtins.int
    REPORT_FIELD_NUMBER: builtins.int
    COUNT_DOWN_SEC_FIELD_NUMBER: builtins.int
    RIGHT_BOTTOM_DESC_FIELD_NUMBER: builtins.int
    BOTTOM_DISPLAY_FIELD_NUMBER: builtins.int
    code: builtins.int
    """鉴权限制码"""

    msg: typing.Text
    """鉴权限制信息"""

    type: typing.Text
    """浮层类型"""

    style_type: typing.Text
    """浮层样式类型"""

    @property
    def config(self) -> global___DialogConfig:
        """浮层配置"""
        pass
    @property
    def title(self) -> global___TextInfo:
        """标题"""
        pass
    @property
    def subtitle(self) -> global___TextInfo:
        """副标题"""
        pass
    @property
    def image(self) -> global___ImageInfo:
        """图片信息"""
        pass
    @property
    def button(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ButtonInfo]:
        """按钮列表"""
        pass
    @property
    def bottom_desc(self) -> global___ButtonInfo:
        """底部描述"""
        pass
    @property
    def report(self) -> global___Report:
        """埋点上报信息"""
        pass
    count_down_sec: builtins.int
    """倒计时 秒"""

    @property
    def right_bottom_desc(self) -> global___TextInfo:
        """右下描述"""
        pass
    @property
    def bottom_display(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___BottomDisplay]:
        """"""
        pass
    def __init__(self,
        *,
        code: builtins.int = ...,
        msg: typing.Text = ...,
        type: typing.Text = ...,
        style_type: typing.Text = ...,
        config: typing.Optional[global___DialogConfig] = ...,
        title: typing.Optional[global___TextInfo] = ...,
        subtitle: typing.Optional[global___TextInfo] = ...,
        image: typing.Optional[global___ImageInfo] = ...,
        button: typing.Optional[typing.Iterable[global___ButtonInfo]] = ...,
        bottom_desc: typing.Optional[global___ButtonInfo] = ...,
        report: typing.Optional[global___Report] = ...,
        count_down_sec: builtins.int = ...,
        right_bottom_desc: typing.Optional[global___TextInfo] = ...,
        bottom_display: typing.Optional[typing.Iterable[global___BottomDisplay]] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["bottom_desc",b"bottom_desc","config",b"config","image",b"image","report",b"report","right_bottom_desc",b"right_bottom_desc","subtitle",b"subtitle","title",b"title"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bottom_desc",b"bottom_desc","bottom_display",b"bottom_display","button",b"button","code",b"code","config",b"config","count_down_sec",b"count_down_sec","image",b"image","msg",b"msg","report",b"report","right_bottom_desc",b"right_bottom_desc","style_type",b"style_type","subtitle",b"subtitle","title",b"title","type",b"type"]) -> None: ...
global___Dialog = Dialog

class DialogConfig(google.protobuf.message.Message):
    """鉴权浮层配置"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    IS_SHOW_COVER_FIELD_NUMBER: builtins.int
    IS_ORIENTATION_ENABLE_FIELD_NUMBER: builtins.int
    IS_NESTED_SCROLL_ENABLE_FIELD_NUMBER: builtins.int
    IS_FORCE_HALFSCREEN_ENABLE_FIELD_NUMBER: builtins.int
    is_show_cover: builtins.bool
    """是否显示高斯模糊背景图"""

    is_orientation_enable: builtins.bool
    """是否响应转屏"""

    is_nested_scroll_enable: builtins.bool
    """是否响应上滑吸顶"""

    is_force_halfscreen_enable: builtins.bool
    """是否强制竖屏"""

    def __init__(self,
        *,
        is_show_cover: builtins.bool = ...,
        is_orientation_enable: builtins.bool = ...,
        is_nested_scroll_enable: builtins.bool = ...,
        is_force_halfscreen_enable: builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["is_force_halfscreen_enable",b"is_force_halfscreen_enable","is_nested_scroll_enable",b"is_nested_scroll_enable","is_orientation_enable",b"is_orientation_enable","is_show_cover",b"is_show_cover"]) -> None: ...
global___DialogConfig = DialogConfig

class Dimension(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    WIDTH_FIELD_NUMBER: builtins.int
    HEIGHT_FIELD_NUMBER: builtins.int
    ROTATE_FIELD_NUMBER: builtins.int
    width: builtins.int
    """"""

    height: builtins.int
    """"""

    rotate: builtins.int
    """"""

    def __init__(self,
        *,
        width: builtins.int = ...,
        height: builtins.int = ...,
        rotate: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["height",b"height","rotate",b"rotate","width",b"width"]) -> None: ...
global___Dimension = Dimension

class DolbyItem(google.protobuf.message.Message):
    """杜比音频信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    class _Type:
        ValueType = typing.NewType('ValueType', builtins.int)
        V: typing_extensions.TypeAlias = ValueType
    class _TypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[DolbyItem._Type.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        NONE: DolbyItem._Type.ValueType  # 0
        """NONE"""

        COMMON: DolbyItem._Type.ValueType  # 1
        """普通杜比音效"""

        ATMOS: DolbyItem._Type.ValueType  # 2
        """全景杜比音效"""

    class Type(_Type, metaclass=_TypeEnumTypeWrapper):
        """杜比类型"""
        pass

    NONE: DolbyItem.Type.ValueType  # 0
    """NONE"""

    COMMON: DolbyItem.Type.ValueType  # 1
    """普通杜比音效"""

    ATMOS: DolbyItem.Type.ValueType  # 2
    """全景杜比音效"""


    TYPE_FIELD_NUMBER: builtins.int
    AUDIO_FIELD_NUMBER: builtins.int
    type: global___DolbyItem.Type.ValueType
    """杜比类型"""

    @property
    def audio(self) -> global___DashItem:
        """音频流"""
        pass
    def __init__(self,
        *,
        type: global___DolbyItem.Type.ValueType = ...,
        audio: typing.Optional[global___DashItem] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["audio",b"audio"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["audio",b"audio","type",b"type"]) -> None: ...
global___DolbyItem = DolbyItem

class EndPage(google.protobuf.message.Message):
    """播放结束页"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    DIALOG_FIELD_NUMBER: builtins.int
    HIDE_FIELD_NUMBER: builtins.int
    @property
    def dialog(self) -> global___Dialog:
        """鉴权浮层"""
        pass
    hide: builtins.bool
    """播放完后是否隐藏end_page"""

    def __init__(self,
        *,
        dialog: typing.Optional[global___Dialog] = ...,
        hide: builtins.bool = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["dialog",b"dialog"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["dialog",b"dialog","hide",b"hide"]) -> None: ...
global___EndPage = EndPage

class Event(google.protobuf.message.Message):
    """事件"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SHAKE_FIELD_NUMBER: builtins.int
    @property
    def shake(self) -> global___Shake:
        """震动"""
        pass
    def __init__(self,
        *,
        shake: typing.Optional[global___Shake] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["shake",b"shake"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["shake",b"shake"]) -> None: ...
global___Event = Event

class FreyaConfig(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    DESC_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    ISSUED_CNT_FIELD_NUMBER: builtins.int
    IS_ALWAYS_SHOW_FIELD_NUMBER: builtins.int
    SCREEN_NUMBER_FIELD_NUMBER: builtins.int
    FULL_SCREEN_NUMBER_FIELD_NUMBER: builtins.int
    desc: typing.Text
    """"""

    type: builtins.int
    """"""

    issued_cnt: builtins.int
    """"""

    is_always_show: builtins.bool
    """"""

    screen_number: builtins.int
    """"""

    full_screen_number: builtins.int
    """"""

    def __init__(self,
        *,
        desc: typing.Text = ...,
        type: builtins.int = ...,
        issued_cnt: builtins.int = ...,
        is_always_show: builtins.bool = ...,
        screen_number: builtins.int = ...,
        full_screen_number: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["desc",b"desc","full_screen_number",b"full_screen_number","is_always_show",b"is_always_show","issued_cnt",b"issued_cnt","screen_number",b"screen_number","type",b"type"]) -> None: ...
global___FreyaConfig = FreyaConfig

class GradientColor(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    START_COLOR_FIELD_NUMBER: builtins.int
    END_COLOR_FIELD_NUMBER: builtins.int
    start_color: typing.Text
    """"""

    end_color: typing.Text
    """"""

    def __init__(self,
        *,
        start_color: typing.Text = ...,
        end_color: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["end_color",b"end_color","start_color",b"start_color"]) -> None: ...
global___GradientColor = GradientColor

class HighDefinitionTrialInfo(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TRIAL_ABLE_FIELD_NUMBER: builtins.int
    REMAINING_TIMES_FIELD_NUMBER: builtins.int
    START_FIELD_NUMBER: builtins.int
    TIME_LENGTH_FIELD_NUMBER: builtins.int
    START_TOAST_FIELD_NUMBER: builtins.int
    END_TOAST_FIELD_NUMBER: builtins.int
    REPORT_FIELD_NUMBER: builtins.int
    QUALITY_OPEN_TIP_BTN_FIELD_NUMBER: builtins.int
    NO_LONGER_TRIAL_BTN_FIELD_NUMBER: builtins.int
    trial_able: builtins.bool
    """"""

    remaining_times: builtins.int
    """"""

    start: builtins.int
    """"""

    time_length: builtins.int
    """"""

    @property
    def start_toast(self) -> global___Toast:
        """"""
        pass
    @property
    def end_toast(self) -> global___Toast:
        """"""
        pass
    @property
    def report(self) -> global___Report:
        """"""
        pass
    @property
    def quality_open_tip_btn(self) -> global___ButtonInfo:
        """"""
        pass
    @property
    def no_longer_trial_btn(self) -> global___ButtonInfo:
        """"""
        pass
    def __init__(self,
        *,
        trial_able: builtins.bool = ...,
        remaining_times: builtins.int = ...,
        start: builtins.int = ...,
        time_length: builtins.int = ...,
        start_toast: typing.Optional[global___Toast] = ...,
        end_toast: typing.Optional[global___Toast] = ...,
        report: typing.Optional[global___Report] = ...,
        quality_open_tip_btn: typing.Optional[global___ButtonInfo] = ...,
        no_longer_trial_btn: typing.Optional[global___ButtonInfo] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["end_toast",b"end_toast","no_longer_trial_btn",b"no_longer_trial_btn","quality_open_tip_btn",b"quality_open_tip_btn","report",b"report","start_toast",b"start_toast"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["end_toast",b"end_toast","no_longer_trial_btn",b"no_longer_trial_btn","quality_open_tip_btn",b"quality_open_tip_btn","remaining_times",b"remaining_times","report",b"report","start",b"start","start_toast",b"start_toast","time_length",b"time_length","trial_able",b"trial_able"]) -> None: ...
global___HighDefinitionTrialInfo = HighDefinitionTrialInfo

class ImageInfo(google.protobuf.message.Message):
    """图片信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    URL_FIELD_NUMBER: builtins.int
    url: typing.Text
    """图片链接"""

    def __init__(self,
        *,
        url: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["url",b"url"]) -> None: ...
global___ImageInfo = ImageInfo

class MultiView(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    BUTTON_MATERIAL_FIELD_NUMBER: builtins.int
    EP_ID_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    AVID_FIELD_NUMBER: builtins.int
    button_material: typing.Text
    """"""

    ep_id: builtins.int
    """"""

    cid: builtins.int
    """"""

    avid: builtins.int
    """"""

    def __init__(self,
        *,
        button_material: typing.Text = ...,
        ep_id: builtins.int = ...,
        cid: builtins.int = ...,
        avid: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["avid",b"avid","button_material",b"button_material","cid",b"cid","ep_id",b"ep_id"]) -> None: ...
global___MultiView = MultiView

class PayTip(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    class OrderReportParamsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor
        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: typing.Text
        value: typing.Text
        def __init__(self,
            *,
            key: typing.Text = ...,
            value: typing.Text = ...,
            ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key",b"key","value",b"value"]) -> None: ...

    TITLE_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    ICON_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    SHOW_TYPE_FIELD_NUMBER: builtins.int
    IMG_FIELD_NUMBER: builtins.int
    BG_DAY_COLOR_FIELD_NUMBER: builtins.int
    BG_NIGHT_COLOR_FIELD_NUMBER: builtins.int
    BG_LINE_COLOR_FIELD_NUMBER: builtins.int
    BG_NIGHT_LINE_COLOR_FIELD_NUMBER: builtins.int
    TEXT_COLOR_FIELD_NUMBER: builtins.int
    TEXT_NIGHT_COLOR_FIELD_NUMBER: builtins.int
    VIEW_START_TIME_FIELD_NUMBER: builtins.int
    BUTTON_FIELD_NUMBER: builtins.int
    URL_OPEN_TYPE_FIELD_NUMBER: builtins.int
    REPORT_FIELD_NUMBER: builtins.int
    ANGLE_STYLE_FIELD_NUMBER: builtins.int
    REPORT_TYPE_FIELD_NUMBER: builtins.int
    ORDER_REPORT_PARAMS_FIELD_NUMBER: builtins.int
    title: typing.Text
    """"""

    url: typing.Text
    """"""

    icon: typing.Text
    """"""

    type: builtins.int
    """"""

    show_type: builtins.int
    """"""

    img: typing.Text
    """"""

    bg_day_color: typing.Text
    """"""

    bg_night_color: typing.Text
    """"""

    bg_line_color: typing.Text
    """"""

    bg_night_line_color: typing.Text
    """"""

    text_color: typing.Text
    """"""

    text_night_color: typing.Text
    """"""

    view_start_time: builtins.int
    """"""

    @property
    def button(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ButtonInfo]:
        """"""
        pass
    url_open_type: builtins.int
    """"""

    @property
    def report(self) -> global___Report:
        """"""
        pass
    angle_style: builtins.int
    """"""

    report_type: builtins.int
    """"""

    @property
    def order_report_params(self) -> google.protobuf.internal.containers.ScalarMap[typing.Text, typing.Text]:
        """"""
        pass
    def __init__(self,
        *,
        title: typing.Text = ...,
        url: typing.Text = ...,
        icon: typing.Text = ...,
        type: builtins.int = ...,
        show_type: builtins.int = ...,
        img: typing.Text = ...,
        bg_day_color: typing.Text = ...,
        bg_night_color: typing.Text = ...,
        bg_line_color: typing.Text = ...,
        bg_night_line_color: typing.Text = ...,
        text_color: typing.Text = ...,
        text_night_color: typing.Text = ...,
        view_start_time: builtins.int = ...,
        button: typing.Optional[typing.Iterable[global___ButtonInfo]] = ...,
        url_open_type: builtins.int = ...,
        report: typing.Optional[global___Report] = ...,
        angle_style: builtins.int = ...,
        report_type: builtins.int = ...,
        order_report_params: typing.Optional[typing.Mapping[typing.Text, typing.Text]] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["report",b"report"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["angle_style",b"angle_style","bg_day_color",b"bg_day_color","bg_line_color",b"bg_line_color","bg_night_color",b"bg_night_color","bg_night_line_color",b"bg_night_line_color","button",b"button","icon",b"icon","img",b"img","order_report_params",b"order_report_params","report",b"report","report_type",b"report_type","show_type",b"show_type","text_color",b"text_color","text_night_color",b"text_night_color","title",b"title","type",b"type","url",b"url","url_open_type",b"url_open_type","view_start_time",b"view_start_time"]) -> None: ...
global___PayTip = PayTip

class PlayAbilityConf(google.protobuf.message.Message):
    """禁用功能配置"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    BACKGROUND_PLAY_DISABLE_FIELD_NUMBER: builtins.int
    FLIP_DISABLE_FIELD_NUMBER: builtins.int
    CAST_DISABLE_FIELD_NUMBER: builtins.int
    FEEDBACK_DISABLE_FIELD_NUMBER: builtins.int
    SUBTITLE_DISABLE_FIELD_NUMBER: builtins.int
    PLAYBACK_RATE_DISABLE_FIELD_NUMBER: builtins.int
    TIME_UP_DISABLE_FIELD_NUMBER: builtins.int
    PLAYBACK_MODE_DISABLE_FIELD_NUMBER: builtins.int
    SCALE_MODE_DISABLE_FIELD_NUMBER: builtins.int
    LIKE_DISABLE_FIELD_NUMBER: builtins.int
    DISLIKE_DISABLE_FIELD_NUMBER: builtins.int
    COIN_DISABLE_FIELD_NUMBER: builtins.int
    ELEC_DISABLE_FIELD_NUMBER: builtins.int
    SHARE_DISABLE_FIELD_NUMBER: builtins.int
    SCREEN_SHOT_DISABLE_FIELD_NUMBER: builtins.int
    LOCK_SCREEN_DISABLE_FIELD_NUMBER: builtins.int
    RECOMMEND_DISABLE_FIELD_NUMBER: builtins.int
    PLAYBACK_SPEED_DISABLE_FIELD_NUMBER: builtins.int
    DEFINITION_DISABLE_FIELD_NUMBER: builtins.int
    SELECTIONS_DISABLE_FIELD_NUMBER: builtins.int
    NEXT_DISABLE_FIELD_NUMBER: builtins.int
    EDIT_DM_DISABLE_FIELD_NUMBER: builtins.int
    SMALL_WINDOW_DISABLE_FIELD_NUMBER: builtins.int
    SHAKE_DISABLE_FIELD_NUMBER: builtins.int
    OUTER_DM_DISABLE_FIELD_NUMBER: builtins.int
    INNER_DM_DISABLE_FIELD_NUMBER: builtins.int
    FREYA_ENTER_DISABLE_FIELD_NUMBER: builtins.int
    DOLBY_DISABLE_FIELD_NUMBER: builtins.int
    FREYA_FULL_DISABLE_FIELD_NUMBER: builtins.int
    SKIP_OPED_SWITCH_DISABLE_FIELD_NUMBER: builtins.int
    RECORD_SCREEN_DISABLE_FIELD_NUMBER: builtins.int
    COLOR_OPTIMIZE_DISABLE_FIELD_NUMBER: builtins.int
    background_play_disable: builtins.bool
    """后台播放"""

    flip_disable: builtins.bool
    """镜像反转"""

    cast_disable: builtins.bool
    """投屏"""

    feedback_disable: builtins.bool
    """反馈"""

    subtitle_disable: builtins.bool
    """字幕"""

    playback_rate_disable: builtins.bool
    """播放速度"""

    time_up_disable: builtins.bool
    """定时停止"""

    playback_mode_disable: builtins.bool
    """播放方式"""

    scale_mode_disable: builtins.bool
    """画面尺寸"""

    like_disable: builtins.bool
    """赞"""

    dislike_disable: builtins.bool
    """踩"""

    coin_disable: builtins.bool
    """投币"""

    elec_disable: builtins.bool
    """充电"""

    share_disable: builtins.bool
    """分享"""

    screen_shot_disable: builtins.bool
    """截图"""

    lock_screen_disable: builtins.bool
    """锁定"""

    recommend_disable: builtins.bool
    """相关推荐"""

    playback_speed_disable: builtins.bool
    """播放速度"""

    definition_disable: builtins.bool
    """清晰度"""

    selections_disable: builtins.bool
    """选集"""

    next_disable: builtins.bool
    """下一集"""

    edit_dm_disable: builtins.bool
    """编辑弹幕"""

    small_window_disable: builtins.bool
    """小窗"""

    shake_disable: builtins.bool
    """震动"""

    outer_dm_disable: builtins.bool
    """外层面板弹幕设置"""

    inner_dm_disable: builtins.bool
    """三点内弹幕设置"""

    freya_enter_disable: builtins.bool
    """一起看入口"""

    dolby_disable: builtins.bool
    """杜比音效"""

    freya_full_disable: builtins.bool
    """全屏一起看入口"""

    skip_oped_switch_disable: builtins.bool
    """"""

    record_screen_disable: builtins.bool
    """"""

    color_optimize_disable: builtins.bool
    """"""

    def __init__(self,
        *,
        background_play_disable: builtins.bool = ...,
        flip_disable: builtins.bool = ...,
        cast_disable: builtins.bool = ...,
        feedback_disable: builtins.bool = ...,
        subtitle_disable: builtins.bool = ...,
        playback_rate_disable: builtins.bool = ...,
        time_up_disable: builtins.bool = ...,
        playback_mode_disable: builtins.bool = ...,
        scale_mode_disable: builtins.bool = ...,
        like_disable: builtins.bool = ...,
        dislike_disable: builtins.bool = ...,
        coin_disable: builtins.bool = ...,
        elec_disable: builtins.bool = ...,
        share_disable: builtins.bool = ...,
        screen_shot_disable: builtins.bool = ...,
        lock_screen_disable: builtins.bool = ...,
        recommend_disable: builtins.bool = ...,
        playback_speed_disable: builtins.bool = ...,
        definition_disable: builtins.bool = ...,
        selections_disable: builtins.bool = ...,
        next_disable: builtins.bool = ...,
        edit_dm_disable: builtins.bool = ...,
        small_window_disable: builtins.bool = ...,
        shake_disable: builtins.bool = ...,
        outer_dm_disable: builtins.bool = ...,
        inner_dm_disable: builtins.bool = ...,
        freya_enter_disable: builtins.bool = ...,
        dolby_disable: builtins.bool = ...,
        freya_full_disable: builtins.bool = ...,
        skip_oped_switch_disable: builtins.bool = ...,
        record_screen_disable: builtins.bool = ...,
        color_optimize_disable: builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["background_play_disable",b"background_play_disable","cast_disable",b"cast_disable","coin_disable",b"coin_disable","color_optimize_disable",b"color_optimize_disable","definition_disable",b"definition_disable","dislike_disable",b"dislike_disable","dolby_disable",b"dolby_disable","edit_dm_disable",b"edit_dm_disable","elec_disable",b"elec_disable","feedback_disable",b"feedback_disable","flip_disable",b"flip_disable","freya_enter_disable",b"freya_enter_disable","freya_full_disable",b"freya_full_disable","inner_dm_disable",b"inner_dm_disable","like_disable",b"like_disable","lock_screen_disable",b"lock_screen_disable","next_disable",b"next_disable","outer_dm_disable",b"outer_dm_disable","playback_mode_disable",b"playback_mode_disable","playback_rate_disable",b"playback_rate_disable","playback_speed_disable",b"playback_speed_disable","recommend_disable",b"recommend_disable","record_screen_disable",b"record_screen_disable","scale_mode_disable",b"scale_mode_disable","screen_shot_disable",b"screen_shot_disable","selections_disable",b"selections_disable","shake_disable",b"shake_disable","share_disable",b"share_disable","skip_oped_switch_disable",b"skip_oped_switch_disable","small_window_disable",b"small_window_disable","subtitle_disable",b"subtitle_disable","time_up_disable",b"time_up_disable"]) -> None: ...
global___PlayAbilityConf = PlayAbilityConf

class PlayAbilityExtConf(google.protobuf.message.Message):
    """云控扩展配置信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ALLOW_CLOSE_SUBTITLE_FIELD_NUMBER: builtins.int
    FREYA_CONFIG_FIELD_NUMBER: builtins.int
    CAST_TIPS_FIELD_NUMBER: builtins.int
    allow_close_subtitle: builtins.bool
    """自定义配置扩展信息"""

    @property
    def freya_config(self) -> global___FreyaConfig:
        """"""
        pass
    @property
    def cast_tips(self) -> global___CastTips:
        """"""
        pass
    def __init__(self,
        *,
        allow_close_subtitle: builtins.bool = ...,
        freya_config: typing.Optional[global___FreyaConfig] = ...,
        cast_tips: typing.Optional[global___CastTips] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cast_tips",b"cast_tips","freya_config",b"freya_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["allow_close_subtitle",b"allow_close_subtitle","cast_tips",b"cast_tips","freya_config",b"freya_config"]) -> None: ...
global___PlayAbilityExtConf = PlayAbilityExtConf

class PlayViewBusinessInfo(google.protobuf.message.Message):
    """其他业务信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    class QualityExtMapEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor
        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.int
        @property
        def value(self) -> global___QualityExtInfo: ...
        def __init__(self,
            *,
            key: builtins.int = ...,
            value: typing.Optional[global___QualityExtInfo] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value",b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key",b"key","value",b"value"]) -> None: ...

    class ExpMapEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor
        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: typing.Text
        value: builtins.int
        def __init__(self,
            *,
            key: typing.Text = ...,
            value: builtins.int = ...,
            ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key",b"key","value",b"value"]) -> None: ...

    IS_PREVIEW_FIELD_NUMBER: builtins.int
    BP_FIELD_NUMBER: builtins.int
    MARLIN_TOKEN_FIELD_NUMBER: builtins.int
    PLAYBACK_SPEED_COLOR_FIELD_NUMBER: builtins.int
    CONTINUE_PLAY_INFO_FIELD_NUMBER: builtins.int
    CLIP_INFO_FIELD_NUMBER: builtins.int
    INLINE_TYPE_FIELD_NUMBER: builtins.int
    EP_WHOLE_DURATION_FIELD_NUMBER: builtins.int
    DIMENSION_FIELD_NUMBER: builtins.int
    QUALITY_EXT_MAP_FIELD_NUMBER: builtins.int
    EXP_MAP_FIELD_NUMBER: builtins.int
    DRM_TECH_TYPE_FIELD_NUMBER: builtins.int
    is_preview: builtins.bool
    """当前视频是否是预览"""

    bp: builtins.bool
    """用户是否承包过"""

    marlin_token: typing.Text
    """drm使用"""

    playback_speed_color: typing.Text
    """倍速动效色值"""

    @property
    def continue_play_info(self) -> global___ContinuePlayInfo:
        """"""
        pass
    @property
    def clip_info(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ClipInfo]:
        """"""
        pass
    inline_type: global___InlineType.ValueType
    """"""

    ep_whole_duration: builtins.int
    """"""

    @property
    def dimension(self) -> global___Dimension:
        """"""
        pass
    @property
    def quality_ext_map(self) -> google.protobuf.internal.containers.MessageMap[builtins.int, global___QualityExtInfo]:
        """"""
        pass
    @property
    def exp_map(self) -> google.protobuf.internal.containers.ScalarMap[typing.Text, builtins.int]:
        """"""
        pass
    drm_tech_type: global___DrmTechType.ValueType
    """"""

    def __init__(self,
        *,
        is_preview: builtins.bool = ...,
        bp: builtins.bool = ...,
        marlin_token: typing.Text = ...,
        playback_speed_color: typing.Text = ...,
        continue_play_info: typing.Optional[global___ContinuePlayInfo] = ...,
        clip_info: typing.Optional[typing.Iterable[global___ClipInfo]] = ...,
        inline_type: global___InlineType.ValueType = ...,
        ep_whole_duration: builtins.int = ...,
        dimension: typing.Optional[global___Dimension] = ...,
        quality_ext_map: typing.Optional[typing.Mapping[builtins.int, global___QualityExtInfo]] = ...,
        exp_map: typing.Optional[typing.Mapping[typing.Text, builtins.int]] = ...,
        drm_tech_type: global___DrmTechType.ValueType = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["continue_play_info",b"continue_play_info","dimension",b"dimension"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bp",b"bp","clip_info",b"clip_info","continue_play_info",b"continue_play_info","dimension",b"dimension","drm_tech_type",b"drm_tech_type","ep_whole_duration",b"ep_whole_duration","exp_map",b"exp_map","inline_type",b"inline_type","is_preview",b"is_preview","marlin_token",b"marlin_token","playback_speed_color",b"playback_speed_color","quality_ext_map",b"quality_ext_map"]) -> None: ...
global___PlayViewBusinessInfo = PlayViewBusinessInfo

class PlayViewReply(google.protobuf.message.Message):
    """播放页信息-响应"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    VIDEO_INFO_FIELD_NUMBER: builtins.int
    PLAY_CONF_FIELD_NUMBER: builtins.int
    BUSINESS_FIELD_NUMBER: builtins.int
    EVENT_FIELD_NUMBER: builtins.int
    VIEW_INFO_FIELD_NUMBER: builtins.int
    PLAY_EXT_CONF_FIELD_NUMBER: builtins.int
    @property
    def video_info(self) -> global___VideoInfo:
        """视频流信息"""
        pass
    @property
    def play_conf(self) -> global___PlayAbilityConf:
        """播放控件用户自定义配置"""
        pass
    @property
    def business(self) -> global___PlayViewBusinessInfo:
        """业务需要的其他信息"""
        pass
    @property
    def event(self) -> global___Event:
        """事件"""
        pass
    @property
    def view_info(self) -> global___ViewInfo:
        """展示信息"""
        pass
    @property
    def play_ext_conf(self) -> global___PlayAbilityExtConf:
        """自定义配置扩展信息"""
        pass
    def __init__(self,
        *,
        video_info: typing.Optional[global___VideoInfo] = ...,
        play_conf: typing.Optional[global___PlayAbilityConf] = ...,
        business: typing.Optional[global___PlayViewBusinessInfo] = ...,
        event: typing.Optional[global___Event] = ...,
        view_info: typing.Optional[global___ViewInfo] = ...,
        play_ext_conf: typing.Optional[global___PlayAbilityExtConf] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["business",b"business","event",b"event","play_conf",b"play_conf","play_ext_conf",b"play_ext_conf","video_info",b"video_info","view_info",b"view_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["business",b"business","event",b"event","play_conf",b"play_conf","play_ext_conf",b"play_ext_conf","video_info",b"video_info","view_info",b"view_info"]) -> None: ...
global___PlayViewReply = PlayViewReply

class PlayViewReq(google.protobuf.message.Message):
    """播放页信息-请求"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    EPID_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    QN_FIELD_NUMBER: builtins.int
    FNVER_FIELD_NUMBER: builtins.int
    FNVAL_FIELD_NUMBER: builtins.int
    DOWNLOAD_FIELD_NUMBER: builtins.int
    FORCE_HOST_FIELD_NUMBER: builtins.int
    FOURK_FIELD_NUMBER: builtins.int
    SPMID_FIELD_NUMBER: builtins.int
    FROM_SPMID_FIELD_NUMBER: builtins.int
    TEENAGERS_MODE_FIELD_NUMBER: builtins.int
    PREFER_CODEC_TYPE_FIELD_NUMBER: builtins.int
    IS_PREVIEW_FIELD_NUMBER: builtins.int
    ROOM_ID_FIELD_NUMBER: builtins.int
    IS_NEED_VIEW_INFO_FIELD_NUMBER: builtins.int
    SCENE_CONTROL_FIELD_NUMBER: builtins.int
    INLINE_SCENE_FIELD_NUMBER: builtins.int
    MATERIAL_NO_FIELD_NUMBER: builtins.int
    epid: builtins.int
    """剧集epid"""

    cid: builtins.int
    """视频cid"""

    qn: builtins.int
    """清晰度"""

    fnver: builtins.int
    """视频流版本"""

    fnval: builtins.int
    """视频流格式"""

    download: builtins.int
    """下载模式
    0:播放 1:flv下载 2:dash下载
    """

    force_host: builtins.int
    """流url强制是用域名
    0:允许使用ip 1:使用http 2:使用https
    """

    fourk: builtins.bool
    """是否4K"""

    spmid: typing.Text
    """当前页spm"""

    from_spmid: typing.Text
    """上一页spm"""

    teenagers_mode: builtins.int
    """青少年模式"""

    prefer_codec_type: global___CodeType.ValueType
    """视频编码"""

    is_preview: builtins.bool
    """是否强制请求预览视频"""

    room_id: builtins.int
    """一起看房间id"""

    is_need_view_info: builtins.bool
    """是否需要展示信息"""

    @property
    def scene_control(self) -> global___SceneControl:
        """场景控制"""
        pass
    inline_scene: global___InlineScene.ValueType
    """"""

    material_no: builtins.int
    """"""

    def __init__(self,
        *,
        epid: builtins.int = ...,
        cid: builtins.int = ...,
        qn: builtins.int = ...,
        fnver: builtins.int = ...,
        fnval: builtins.int = ...,
        download: builtins.int = ...,
        force_host: builtins.int = ...,
        fourk: builtins.bool = ...,
        spmid: typing.Text = ...,
        from_spmid: typing.Text = ...,
        teenagers_mode: builtins.int = ...,
        prefer_codec_type: global___CodeType.ValueType = ...,
        is_preview: builtins.bool = ...,
        room_id: builtins.int = ...,
        is_need_view_info: builtins.bool = ...,
        scene_control: typing.Optional[global___SceneControl] = ...,
        inline_scene: global___InlineScene.ValueType = ...,
        material_no: builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["scene_control",b"scene_control"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cid",b"cid","download",b"download","epid",b"epid","fnval",b"fnval","fnver",b"fnver","force_host",b"force_host","fourk",b"fourk","from_spmid",b"from_spmid","inline_scene",b"inline_scene","is_need_view_info",b"is_need_view_info","is_preview",b"is_preview","material_no",b"material_no","prefer_codec_type",b"prefer_codec_type","qn",b"qn","room_id",b"room_id","scene_control",b"scene_control","spmid",b"spmid","teenagers_mode",b"teenagers_mode"]) -> None: ...
global___PlayViewReq = PlayViewReq

class PopWin(google.protobuf.message.Message):
    """弹窗信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TITLE_FIELD_NUMBER: builtins.int
    COUPON_FIELD_NUMBER: builtins.int
    BUTTON_FIELD_NUMBER: builtins.int
    BOTTOM_TEXT_FIELD_NUMBER: builtins.int
    POP_TITLE_FIELD_NUMBER: builtins.int
    SUBTITLE_FIELD_NUMBER: builtins.int
    BOTTOM_DESC_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    POP_TYPE_FIELD_NUMBER: builtins.int
    title: typing.Text
    """弹窗标题 老字段"""

    @property
    def coupon(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Coupon]:
        """优惠券列表"""
        pass
    @property
    def button(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ButtonInfo]:
        """弹窗按钮列表"""
        pass
    bottom_text: typing.Text
    """底部文案 老字段"""

    @property
    def pop_title(self) -> global___TextInfo:
        """弹窗标题 新字段"""
        pass
    @property
    def subtitle(self) -> global___TextInfo:
        """弹窗副标题"""
        pass
    @property
    def bottom_desc(self) -> global___ButtonInfo:
        """底部描述 新字段"""
        pass
    cover: typing.Text
    """弹窗小图"""

    pop_type: typing.Text
    """弹窗类型"""

    def __init__(self,
        *,
        title: typing.Text = ...,
        coupon: typing.Optional[typing.Iterable[global___Coupon]] = ...,
        button: typing.Optional[typing.Iterable[global___ButtonInfo]] = ...,
        bottom_text: typing.Text = ...,
        pop_title: typing.Optional[global___TextInfo] = ...,
        subtitle: typing.Optional[global___TextInfo] = ...,
        bottom_desc: typing.Optional[global___ButtonInfo] = ...,
        cover: typing.Text = ...,
        pop_type: typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["bottom_desc",b"bottom_desc","pop_title",b"pop_title","subtitle",b"subtitle"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bottom_desc",b"bottom_desc","bottom_text",b"bottom_text","button",b"button","coupon",b"coupon","cover",b"cover","pop_title",b"pop_title","pop_type",b"pop_type","subtitle",b"subtitle","title",b"title"]) -> None: ...
global___PopWin = PopWin

class PromptBar(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TITLE_FIELD_NUMBER: builtins.int
    SUB_TITLE_FIELD_NUMBER: builtins.int
    SUB_TITLE_ICON_FIELD_NUMBER: builtins.int
    BG_IMAGE_FIELD_NUMBER: builtins.int
    BG_GRADIENT_COLOR_FIELD_NUMBER: builtins.int
    BUTTON_FIELD_NUMBER: builtins.int
    REPORT_FIELD_NUMBER: builtins.int
    FULL_SCREEN_IP_ICON_FIELD_NUMBER: builtins.int
    FULL_SCREEN_BG_GRADIENT_COLOR_FIELD_NUMBER: builtins.int
    @property
    def title(self) -> global___TextInfo:
        """"""
        pass
    @property
    def sub_title(self) -> global___TextInfo:
        """"""
        pass
    sub_title_icon: typing.Text
    """"""

    bg_image: typing.Text
    """"""

    @property
    def bg_gradient_color(self) -> global___GradientColor:
        """"""
        pass
    @property
    def button(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ButtonInfo]:
        """"""
        pass
    @property
    def report(self) -> global___Report:
        """"""
        pass
    full_screen_ip_icon: typing.Text
    """"""

    @property
    def full_screen_bg_gradient_color(self) -> global___GradientColor:
        """"""
        pass
    def __init__(self,
        *,
        title: typing.Optional[global___TextInfo] = ...,
        sub_title: typing.Optional[global___TextInfo] = ...,
        sub_title_icon: typing.Text = ...,
        bg_image: typing.Text = ...,
        bg_gradient_color: typing.Optional[global___GradientColor] = ...,
        button: typing.Optional[typing.Iterable[global___ButtonInfo]] = ...,
        report: typing.Optional[global___Report] = ...,
        full_screen_ip_icon: typing.Text = ...,
        full_screen_bg_gradient_color: typing.Optional[global___GradientColor] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["bg_gradient_color",b"bg_gradient_color","full_screen_bg_gradient_color",b"full_screen_bg_gradient_color","report",b"report","sub_title",b"sub_title","title",b"title"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bg_gradient_color",b"bg_gradient_color","bg_image",b"bg_image","button",b"button","full_screen_bg_gradient_color",b"full_screen_bg_gradient_color","full_screen_ip_icon",b"full_screen_ip_icon","report",b"report","sub_title",b"sub_title","sub_title_icon",b"sub_title_icon","title",b"title"]) -> None: ...
global___PromptBar = PromptBar

class QualityExtInfo(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TRIAL_SUPPORT_FIELD_NUMBER: builtins.int
    trial_support: builtins.bool
    """"""

    def __init__(self,
        *,
        trial_support: builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["trial_support",b"trial_support"]) -> None: ...
global___QualityExtInfo = QualityExtInfo

class Report(google.protobuf.message.Message):
    """埋点上报信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SHOW_EVENT_ID_FIELD_NUMBER: builtins.int
    CLICK_EVENT_ID_FIELD_NUMBER: builtins.int
    EXTENDS_FIELD_NUMBER: builtins.int
    show_event_id: typing.Text
    """曝光事件"""

    click_event_id: typing.Text
    """点击事件"""

    extends: typing.Text
    """埋点透传参数"""

    def __init__(self,
        *,
        show_event_id: typing.Text = ...,
        click_event_id: typing.Text = ...,
        extends: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["click_event_id",b"click_event_id","extends",b"extends","show_event_id",b"show_event_id"]) -> None: ...
global___Report = Report

class ResponseUrl(google.protobuf.message.Message):
    """分段流条目"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ORDER_FIELD_NUMBER: builtins.int
    LENGTH_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    BACKUP_URL_FIELD_NUMBER: builtins.int
    MD5_FIELD_NUMBER: builtins.int
    order: builtins.int
    """分段序号"""

    length: builtins.int
    """分段时长"""

    size: builtins.int
    """分段大小"""

    url: typing.Text
    """主线流"""

    @property
    def backup_url(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]:
        """备用流"""
        pass
    md5: typing.Text
    """md5"""

    def __init__(self,
        *,
        order: builtins.int = ...,
        length: builtins.int = ...,
        size: builtins.int = ...,
        url: typing.Text = ...,
        backup_url: typing.Optional[typing.Iterable[typing.Text]] = ...,
        md5: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["backup_url",b"backup_url","length",b"length","md5",b"md5","order",b"order","size",b"size","url",b"url"]) -> None: ...
global___ResponseUrl = ResponseUrl

class SceneControl(google.protobuf.message.Message):
    """场景控制"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    FAV_PLAYLIST_FIELD_NUMBER: builtins.int
    SMALL_WINDOW_FIELD_NUMBER: builtins.int
    PIP_FIELD_NUMBER: builtins.int
    WAS_HE_INLINE_FIELD_NUMBER: builtins.int
    IS_NEED_TRIAL_FIELD_NUMBER: builtins.int
    fav_playlist: builtins.bool
    """是否收藏播单"""

    small_window: builtins.bool
    """是否小窗"""

    pip: builtins.bool
    """是否画中画"""

    was_he_inline: builtins.bool
    """"""

    is_need_trial: builtins.bool
    """"""

    def __init__(self,
        *,
        fav_playlist: builtins.bool = ...,
        small_window: builtins.bool = ...,
        pip: builtins.bool = ...,
        was_he_inline: builtins.bool = ...,
        is_need_trial: builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["fav_playlist",b"fav_playlist","is_need_trial",b"is_need_trial","pip",b"pip","small_window",b"small_window","was_he_inline",b"was_he_inline"]) -> None: ...
global___SceneControl = SceneControl

class SegmentVideo(google.protobuf.message.Message):
    """分段视频流"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SEGMENT_FIELD_NUMBER: builtins.int
    @property
    def segment(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ResponseUrl]:
        """分段视频流列表"""
        pass
    def __init__(self,
        *,
        segment: typing.Optional[typing.Iterable[global___ResponseUrl]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["segment",b"segment"]) -> None: ...
global___SegmentVideo = SegmentVideo

class Shake(google.protobuf.message.Message):
    """震动"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    FILE_FIELD_NUMBER: builtins.int
    file: typing.Text
    """文件地址"""

    def __init__(self,
        *,
        file: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["file",b"file"]) -> None: ...
global___Shake = Shake

class Stream(google.protobuf.message.Message):
    """视频流信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INFO_FIELD_NUMBER: builtins.int
    DASH_VIDEO_FIELD_NUMBER: builtins.int
    SEGMENT_VIDEO_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___StreamInfo:
        """元数据"""
        pass
    @property
    def dash_video(self) -> global___DashVideo:
        """dash流"""
        pass
    @property
    def segment_video(self) -> global___SegmentVideo:
        """分段流"""
        pass
    def __init__(self,
        *,
        info: typing.Optional[global___StreamInfo] = ...,
        dash_video: typing.Optional[global___DashVideo] = ...,
        segment_video: typing.Optional[global___SegmentVideo] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["content",b"content","dash_video",b"dash_video","info",b"info","segment_video",b"segment_video"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["content",b"content","dash_video",b"dash_video","info",b"info","segment_video",b"segment_video"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["content",b"content"]) -> typing.Optional[typing_extensions.Literal["dash_video","segment_video"]]: ...
global___Stream = Stream

class StreamInfo(google.protobuf.message.Message):
    """流媒体元数据"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    QUALITY_FIELD_NUMBER: builtins.int
    FORMAT_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ERR_CODE_FIELD_NUMBER: builtins.int
    LIMIT_FIELD_NUMBER: builtins.int
    NEED_VIP_FIELD_NUMBER: builtins.int
    NEED_LOGIN_FIELD_NUMBER: builtins.int
    INTACT_FIELD_NUMBER: builtins.int
    NO_REXCODE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    NEW_DESCRIPTION_FIELD_NUMBER: builtins.int
    DISPLAY_DESC_FIELD_NUMBER: builtins.int
    SUPERSCRIPT_FIELD_NUMBER: builtins.int
    quality: builtins.int
    """清晰度"""

    format: typing.Text
    """格式"""

    description: typing.Text
    """格式描述"""

    err_code: builtins.int
    """错误码"""

    @property
    def limit(self) -> global___StreamLimit:
        """不满足条件信息"""
        pass
    need_vip: builtins.bool
    """是否需要vip"""

    need_login: builtins.bool
    """是否需要登录"""

    intact: builtins.bool
    """是否完整"""

    no_rexcode: builtins.bool
    """是否非全二压"""

    attribute: builtins.int
    """清晰度属性位"""

    new_description: typing.Text
    """新版格式描述"""

    display_desc: typing.Text
    """格式文字"""

    superscript: typing.Text
    """新版格式描述备注"""

    def __init__(self,
        *,
        quality: builtins.int = ...,
        format: typing.Text = ...,
        description: typing.Text = ...,
        err_code: builtins.int = ...,
        limit: typing.Optional[global___StreamLimit] = ...,
        need_vip: builtins.bool = ...,
        need_login: builtins.bool = ...,
        intact: builtins.bool = ...,
        no_rexcode: builtins.bool = ...,
        attribute: builtins.int = ...,
        new_description: typing.Text = ...,
        display_desc: typing.Text = ...,
        superscript: typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["limit",b"limit"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["attribute",b"attribute","description",b"description","display_desc",b"display_desc","err_code",b"err_code","format",b"format","intact",b"intact","limit",b"limit","need_login",b"need_login","need_vip",b"need_vip","new_description",b"new_description","no_rexcode",b"no_rexcode","quality",b"quality","superscript",b"superscript"]) -> None: ...
global___StreamInfo = StreamInfo

class StreamLimit(google.protobuf.message.Message):
    """清晰度不满足条件信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TITLE_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    MSG_FIELD_NUMBER: builtins.int
    title: typing.Text
    """标题"""

    uri: typing.Text
    """跳转地址"""

    msg: typing.Text
    """提示信息"""

    def __init__(self,
        *,
        title: typing.Text = ...,
        uri: typing.Text = ...,
        msg: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["msg",b"msg","title",b"title","uri",b"uri"]) -> None: ...
global___StreamLimit = StreamLimit

class TextInfo(google.protobuf.message.Message):
    """文案信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TEXT_FIELD_NUMBER: builtins.int
    TEXTCOLOR_FIELD_NUMBER: builtins.int
    TEXTCOLORNIGHT_FIELD_NUMBER: builtins.int
    text: typing.Text
    """文案"""

    textColor: typing.Text
    """字体色值"""

    textColorNight: typing.Text
    """字体色值-夜间模式"""

    def __init__(self,
        *,
        text: typing.Text = ...,
        textColor: typing.Text = ...,
        textColorNight: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["text",b"text","textColor",b"textColor","textColorNight",b"textColorNight"]) -> None: ...
global___TextInfo = TextInfo

class Toast(google.protobuf.message.Message):
    """toast"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    class OrderReportParamsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor
        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: typing.Text
        value: typing.Text
        def __init__(self,
            *,
            key: typing.Text = ...,
            value: typing.Text = ...,
            ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key",b"key","value",b"value"]) -> None: ...

    TEXT_FIELD_NUMBER: builtins.int
    BUTTON_FIELD_NUMBER: builtins.int
    SHOW_STYLE_TYPE_FIELD_NUMBER: builtins.int
    ICON_FIELD_NUMBER: builtins.int
    TOAST_TEXT_FIELD_NUMBER: builtins.int
    REPORT_FIELD_NUMBER: builtins.int
    ORDER_REPORT_PARAMS_FIELD_NUMBER: builtins.int
    text: typing.Text
    """toast文案 老字段"""

    @property
    def button(self) -> global___ButtonInfo:
        """toast按钮"""
        pass
    show_style_type: builtins.int
    """显示样式类型"""

    icon: typing.Text
    """图标"""

    @property
    def toast_text(self) -> global___TextInfo:
        """toast文案 新字段"""
        pass
    @property
    def report(self) -> global___Report:
        """埋点上报信息"""
        pass
    @property
    def order_report_params(self) -> google.protobuf.internal.containers.ScalarMap[typing.Text, typing.Text]:
        """"""
        pass
    def __init__(self,
        *,
        text: typing.Text = ...,
        button: typing.Optional[global___ButtonInfo] = ...,
        show_style_type: builtins.int = ...,
        icon: typing.Text = ...,
        toast_text: typing.Optional[global___TextInfo] = ...,
        report: typing.Optional[global___Report] = ...,
        order_report_params: typing.Optional[typing.Mapping[typing.Text, typing.Text]] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["button",b"button","report",b"report","toast_text",b"toast_text"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["button",b"button","icon",b"icon","order_report_params",b"order_report_params","report",b"report","show_style_type",b"show_style_type","text",b"text","toast_text",b"toast_text"]) -> None: ...
global___Toast = Toast

class VideoInfo(google.protobuf.message.Message):
    """视频url信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    QUALITY_FIELD_NUMBER: builtins.int
    FORMAT_FIELD_NUMBER: builtins.int
    TIMELENGTH_FIELD_NUMBER: builtins.int
    VIDEO_CODECID_FIELD_NUMBER: builtins.int
    STREAM_LIST_FIELD_NUMBER: builtins.int
    DASH_AUDIO_FIELD_NUMBER: builtins.int
    DOLBY_FIELD_NUMBER: builtins.int
    quality: builtins.int
    """视频清晰度"""

    format: typing.Text
    """视频格式"""

    timelength: builtins.int
    """视频时长"""

    video_codecid: builtins.int
    """视频编码id"""

    @property
    def stream_list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Stream]:
        """视频流"""
        pass
    @property
    def dash_audio(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DashItem]:
        """伴音流"""
        pass
    @property
    def dolby(self) -> global___DolbyItem:
        """杜比伴音流"""
        pass
    def __init__(self,
        *,
        quality: builtins.int = ...,
        format: typing.Text = ...,
        timelength: builtins.int = ...,
        video_codecid: builtins.int = ...,
        stream_list: typing.Optional[typing.Iterable[global___Stream]] = ...,
        dash_audio: typing.Optional[typing.Iterable[global___DashItem]] = ...,
        dolby: typing.Optional[global___DolbyItem] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["dolby",b"dolby"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["dash_audio",b"dash_audio","dolby",b"dolby","format",b"format","quality",b"quality","stream_list",b"stream_list","timelength",b"timelength","video_codecid",b"video_codecid"]) -> None: ...
global___VideoInfo = VideoInfo

class ViewInfo(google.protobuf.message.Message):
    """展示信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    class ExpConfigEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor
        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: typing.Text
        value: builtins.bool
        def __init__(self,
            *,
            key: typing.Text = ...,
            value: builtins.bool = ...,
            ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key",b"key","value",b"value"]) -> None: ...

    class ExtDialogEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor
        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: typing.Text
        @property
        def value(self) -> global___Dialog: ...
        def __init__(self,
            *,
            key: typing.Text = ...,
            value: typing.Optional[global___Dialog] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value",b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key",b"key","value",b"value"]) -> None: ...

    DIALOG_FIELD_NUMBER: builtins.int
    TOAST_FIELD_NUMBER: builtins.int
    COUPON_INFO_FIELD_NUMBER: builtins.int
    DEMAND_NO_PAY_EPIDS_FIELD_NUMBER: builtins.int
    END_PAGE_FIELD_NUMBER: builtins.int
    EXP_CONFIG_FIELD_NUMBER: builtins.int
    POP_WIN_FIELD_NUMBER: builtins.int
    TRY_WATCH_PROMPT_BAR_FIELD_NUMBER: builtins.int
    PAY_TIP_FIELD_NUMBER: builtins.int
    HIGH_DEFINITION_TRIAL_INFO_FIELD_NUMBER: builtins.int
    EXT_DIALOG_FIELD_NUMBER: builtins.int
    @property
    def dialog(self) -> global___Dialog:
        """鉴权浮层"""
        pass
    @property
    def toast(self) -> global___Toast:
        """toast"""
        pass
    @property
    def coupon_info(self) -> global___CouponInfo:
        """优惠券信息"""
        pass
    @property
    def demand_no_pay_epids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]:
        """未购买的超前点播ep列表"""
        pass
    @property
    def end_page(self) -> global___EndPage:
        """播放结束页"""
        pass
    @property
    def exp_config(self) -> google.protobuf.internal.containers.ScalarMap[typing.Text, builtins.bool]:
        """"""
        pass
    @property
    def pop_win(self) -> global___PopWin:
        """弹窗"""
        pass
    @property
    def try_watch_prompt_bar(self) -> global___PromptBar:
        """"""
        pass
    @property
    def pay_tip(self) -> global___PayTip:
        """"""
        pass
    @property
    def high_definition_trial_info(self) -> global___HighDefinitionTrialInfo:
        """"""
        pass
    @property
    def ext_dialog(self) -> google.protobuf.internal.containers.MessageMap[typing.Text, global___Dialog]:
        """"""
        pass
    def __init__(self,
        *,
        dialog: typing.Optional[global___Dialog] = ...,
        toast: typing.Optional[global___Toast] = ...,
        coupon_info: typing.Optional[global___CouponInfo] = ...,
        demand_no_pay_epids: typing.Optional[typing.Iterable[builtins.int]] = ...,
        end_page: typing.Optional[global___EndPage] = ...,
        exp_config: typing.Optional[typing.Mapping[typing.Text, builtins.bool]] = ...,
        pop_win: typing.Optional[global___PopWin] = ...,
        try_watch_prompt_bar: typing.Optional[global___PromptBar] = ...,
        pay_tip: typing.Optional[global___PayTip] = ...,
        high_definition_trial_info: typing.Optional[global___HighDefinitionTrialInfo] = ...,
        ext_dialog: typing.Optional[typing.Mapping[typing.Text, global___Dialog]] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["coupon_info",b"coupon_info","dialog",b"dialog","end_page",b"end_page","high_definition_trial_info",b"high_definition_trial_info","pay_tip",b"pay_tip","pop_win",b"pop_win","toast",b"toast","try_watch_prompt_bar",b"try_watch_prompt_bar"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["coupon_info",b"coupon_info","demand_no_pay_epids",b"demand_no_pay_epids","dialog",b"dialog","end_page",b"end_page","exp_config",b"exp_config","ext_dialog",b"ext_dialog","high_definition_trial_info",b"high_definition_trial_info","pay_tip",b"pay_tip","pop_win",b"pop_win","toast",b"toast","try_watch_prompt_bar",b"try_watch_prompt_bar"]) -> None: ...
global___ViewInfo = ViewInfo
